decode

Function decode 

pub fn decode(table: &[u8; 64], src: &[u8], dst: &mut [u8]) -> Option<usize>
Decoding function writing to slice.

Arguments

  • src - Input to decode;
  • dst - Output to write;

Result

Returns Some if successful, containing number of bytes written.

Returns None if data cannot be encoded due to insufficient buffer size or invalid input.