Function based64::encode_len
source · pub const fn encode_len(input: usize) -> usizeExpand description
Returns number of bytes necessary to encode input of provided size (including padding).
On overflow returns wrapped value.
pub const fn encode_len(input: usize) -> usizeReturns number of bytes necessary to encode input of provided size (including padding).
On overflow returns wrapped value.