Function based64::decode

source ·
pub fn decode(table: &[u8; 64], src: &[u8], dst: &mut [u8]) -> Option<usize>
Decoding function writing to slice.

src - Input to decode; dst - Output to write;

Returns Some if successful, containing number of bytes written. Returns None if data cannot be encoded due to insufficient buffer size.